==> typo3_src-9.5.14.tar.gz: typo3_src-9.5.14/typo3/sysext/install/Configuration/ExtensionScanner/Php/MethodArgumentUnusedMatcher.php <==
<?php
return [
    'TYPO3\CMS\Core\Html\RteHtmlParser->RTE_transform' => [
        'unusedArgumentNumbers' => [ 2 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79341-MethodsRelatedToRichtextConfiguration.rst',
        ],
    ],
    'TYPO3\CMS\Core\Localization\LocalizationFactory->getParsedData' => [
        'unusedArgumentNumbers' => [ 3, 4 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-80486-SettingCharsetViaLocalizationParserInterface-getParsedData.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\TemplateService->linkData' => [
        'unusedArgumentNumbers' => [ 4 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->whichWorkspace' => [
        'unusedArgumentNumbers' => [ 1 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-80485-MethodParameterOfTSFE-whichWorkspaceToReturnTheWorkspaceTitle.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->TS_AtagToAbs' => [
        'unusedArgumentNumbers' => [ 2 ],
        'restFiles' => [
            'Deprecation-83252-Link-tagSyntaxProcesssing.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->__construct' => [
        'unusedArgumentNumbers' => [ 4 ],
        'restFiles' => [
            'Deprecation-86002-TSFEConstructorWithNo_cacheArgument.rst',
        ],
    ],
];

==> typo3_src-10.3.0.tar.gz: typo3_src-10.3.0/typo3/sysext/install/Configuration/ExtensionScanner/Php/MethodArgumentUnusedMatcher.php <==
<?php
return [
    'TYPO3\CMS\Core\Html\RteHtmlParser->RTE_transform' => [
        'unusedArgumentNumbers' => [ 2 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79341-MethodsRelatedToRichtextConfiguration.rst',
        ],
    ],
    'TYPO3\CMS\Core\Localization\LocalizationFactory->getParsedData' => [
        'unusedArgumentNumbers' => [ 3, 4 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-80486-SettingCharsetViaLocalizationParserInterface-getParsedData.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\TemplateService->linkData' => [
        'unusedArgumentNumbers' => [ 4 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->whichWorkspace' => [
        'unusedArgumentNumbers' => [ 1 ],
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-80485-MethodParameterOfTSFE-whichWorkspaceToReturnTheWorkspaceTitle.rst',
        ],
    ],
    'TYPO3\CMS\Core\Html\RteHtmlParser->TS_AtagToAbs' => [
        'unusedArgumentNumbers' => [ 2 ],
        'restFiles' => [
            'Deprecation-83252-Link-tagSyntaxProcesssing.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController->__construct' => [
        'unusedArgumentNumbers' => [ 4 ],
        'restFiles' => [
            'Deprecation-86002-TSFEConstructorWithNo_cacheArgument.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
];
